#!/bin/bash
source ./tools/functions.sh
source ./tools/checkRequisitesFunctions.sh
checkRoot

FIRST_PARAMETER=$1
SECOND_PARAMETER=$2
IS_UPDATE="false"
IS_UPDATE_CLIENTS="false"

if [[ $FIRST_PARAMETER == "--isUpdate" ]]
then
	IS_UPDATE="true"
fi

if [[ $SECOND_PARAMETER == "--isUpdateClients" ]]
then
	IS_UPDATE_CLIENTS="true"
fi

KOP_POSSIBLE_ERROR_ON_INSTALL="0"
LOG_FILE_PREREQUISITES_PREREQUISITES="logs/check-prerequisites.log"

VOLUMES_PROPERTIES_FILE="./config/volumes.properties"
CONFIG_SHARED_PATH=$(getProperty "config.shared" $VOLUMES_PROPERTIES_FILE)
DATA_SHARED_PATH=$(getProperty "data.shared" $VOLUMES_PROPERTIES_FILE)
DATA_LOCAL_PATH=$(getProperty "data.local" $VOLUMES_PROPERTIES_FILE)
GLOBAL_CONFIG_PATH=$CONFIG_SHARED_PATH/globalConfig/globalConfig.properties
UPDATE_CLIENTS_FLAG=$(getProperty "kiuwan.clients.update" $GLOBAL_CONFIG_PATH)

APACHE_IS_EXTERNALIZE=$(getProperty "kiuwan.externalize.apacheloadbalancer" $GLOBAL_CONFIG_PATH)
REDIS_STORAGE_IS_EXTERNALIZE=$(getProperty "kiuwan.externalize.redis.storage" $GLOBAL_CONFIG_PATH)
REDIS_CACHE_IS_EXTERNALIZE=$(getProperty "kiuwan.externalize.redis.cache" $GLOBAL_CONFIG_PATH)
MYSQL_IS_EXTERNALIZE=$(getProperty "kiuwan.externalize.mysql" $GLOBAL_CONFIG_PATH)

function printPortAvailable {
	local PORT_VAR=$1
  local PORT_NUMBER=$2
	local REASON=$3
  if [ "$PORT_VAR" -eq "0" ]; then
    echo -e "[\e[92m OK \e[0m] $PORT_NUMBER" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
  else
    echo -e "[\e[91mFAIL\e[0m] $PORT_NUMBER needed for $REASON" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
		KOP_POSSIBLE_ERROR_ON_INSTALL="1"
  fi
}

function printCommandAvailable {
	local COMMAND_RESULT=$1
  local COMMAND_NAME=$2
  if [ "$COMMAND_RESULT" -eq "0" ]; then
    echo -e "[\e[92m OK \e[0m] $COMMAND_NAME" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
  else
    echo -e "[\e[91mFAIL\e[0m] $COMMAND_NAME not found" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
		KOP_POSSIBLE_ERROR_ON_INSTALL="1"
  fi
}

function printFileExists {
	local FILE_EXISTS=$1
  local FILE_NAME=$2
  if [ "$FILE_EXISTS" == "true" ]; then
    echo -e "[\e[92m OK \e[0m] $FILE_NAME" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
  else
    echo -e "[\e[91mFAIL\e[0m] $FILE_NAME not found" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
		KOP_POSSIBLE_ERROR_ON_INSTALL="1"
  fi
}

function printCommandVersion {
	local COMMAND_NAME=$1
  local COMMAND_VERSION=$2
	local COMMAND_MIN_VERSION=$3

	VERSION_COMPARE=$(versionHigher $COMMAND_VERSION $COMMAND_MIN_VERSION)
	VERSION_COMPARE=$?
	if [ "$VERSION_COMPARE" -eq "2" ]; then
		echo -e "[\e[91mFAIL\e[0m] $COMMAND_NAME $COMMAND_VERSION (required >=$COMMAND_MIN_VERSION)" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
		KOP_POSSIBLE_ERROR_ON_INSTALL="1"
	else
		echo -e "[\e[92m OK \e[0m] $COMMAND_NAME $COMMAND_VERSION " 2>&1 | tee -a $LOG_FILE_PREREQUISITES
	fi
}

if [[ $IS_UPDATE == "false" ]]
then
	echo "******************************************************************" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
	echo "CHECK PRE-REQUISITES KIUWAN" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
	echo "******************************************************************" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
else
	echo "******************************************************************" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
	echo "CHECK UPDATE PRE-REQUISITES KIUWAN" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
	echo "******************************************************************" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
fi
CURRENTDIR=`pwd`
if [[ $IS_UPDATE == "false" ]]
then
	echo "" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
	echo "Checking ports" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
	echo "--------------" 2>&1 | tee -a $LOG_FILE_PREREQUISITES

	if [ -d $DATA_SHARED_PATH ]
	then
		KIUWAN_PORT_NUMBER=$(getProperty "kiuwan.port" $GLOBAL_CONFIG_PATH)
		KIUWAN_PORT=$(checkPortIsNotUsed $KIUWAN_PORT_NUMBER)
		printPortAvailable $KIUWAN_PORT $KIUWAN_PORT_NUMBER "Kiuwan On-Premises public access port"
	else
		echo -e "[\e[91mFAIL\e[0m] sets the data-shared volume to check Kiuwan On-Premises public access port." 2>&1 | tee -a $LOG_FILE_PREREQUISITES
		KOP_POSSIBLE_ERROR_ON_INSTALL="1"
	fi

	if [[ $MYSQL_IS_EXTERNALIZE == "false" ]]
	then
		PORT_3306_NUMBER=$(getProperty "kiuwan.port.mysql" $GLOBAL_CONFIG_PATH)
		if [ -z "$PORT_3306_NUMBER" ]
    then
      PORT_3306_NUMBER=3306
    fi
		PORT_3306=$(checkPortIsNotUsed $PORT_3306_NUMBER)
		printPortAvailable $PORT_3306 $PORT_3306_NUMBER "MySQL database"
	fi

	if [[ $REDIS_STORAGE_IS_EXTERNALIZE == "false" ]] || [[ $REDIS_CACHE_IS_EXTERNALIZE == "false" ]]
	then
		PORT_6379_NUMBER=6379
		PORT_6379=$(checkPortIsNotUsed $PORT_6379_NUMBER)
		printPortAvailable $PORT_6379 $PORT_6379_NUMBER "Redis cluster node 1"

		PORT_6380_NUMBER=6380
		PORT_6380=$(checkPortIsNotUsed $PORT_6380_NUMBER)
		printPortAvailable $PORT_6380 $PORT_6380_NUMBER "Redis cluster node 2"

		PORT_6381_NUMBER=6381
		PORT_6381=$(checkPortIsNotUsed $PORT_6381_NUMBER)
		printPortAvailable $PORT_6381 $PORT_6381_NUMBER "Redis cluster node 3"

		PORT_6382_NUMBER=6382
		PORT_6382=$(checkPortIsNotUsed $PORT_6382_NUMBER)
		printPortAvailable $PORT_6382 $PORT_6382_NUMBER "Redis cluster node 4"

		PORT_6383_NUMBER=6383
		PORT_6383=$(checkPortIsNotUsed $PORT_6383_NUMBER)
		printPortAvailable $PORT_6383 $PORT_6383_NUMBER "Redis cluster node 5"

		PORT_6384_NUMBER=6384
		PORT_6384=$(checkPortIsNotUsed $PORT_6384_NUMBER)
		printPortAvailable $PORT_6384 $PORT_6384_NUMBER "Redis cluster node 6"
  fi

	PORT_8143_NUMBER=$(getProperty "kiuwan.port.front1" $GLOBAL_CONFIG_PATH)
	if [ -z "$PORT_8143_NUMBER" ]
	then
		PORT_8143_NUMBER=8143
	fi
	PORT_8143=$(checkPortIsNotUsed $PORT_8143_NUMBER)
	printPortAvailable $PORT_8143 $PORT_8143_NUMBER "Kiuwan front 1"

	PORT_8243_NUMBER=$(getProperty "kiuwan.port.front2" $GLOBAL_CONFIG_PATH)
	if [ -z "$PORT_8243_NUMBER" ]
	then
		PORT_8243_NUMBER=8243
	fi
	PORT_8243=$(checkPortIsNotUsed $PORT_8243_NUMBER)
	printPortAvailable $PORT_8243 $PORT_8243_NUMBER "Kiuwan front 2"

	PORT_8343_NUMBER=$(getProperty "kiuwan.port.front3" $GLOBAL_CONFIG_PATH)
	if [ -z "$PORT_8343_NUMBER" ]
	then
		PORT_8343_NUMBER=8343
	fi
	PORT_8343=$(checkPortIsNotUsed $PORT_8343_NUMBER)
	printPortAvailable $PORT_8343 $PORT_8343_NUMBER "Kiuwan front 3"

	PORT_8443_NUMBER=$(getProperty "kiuwan.port.front4" $GLOBAL_CONFIG_PATH)
	if [ -z "$PORT_8443_NUMBER" ]
	then
		PORT_8443_NUMBER=8443
	fi
	PORT_8443=$(checkPortIsNotUsed $PORT_8443_NUMBER)
	printPortAvailable $PORT_8443 $PORT_8443_NUMBER "Kiuwan front 4"

	PORT_8543_NUMBER=$(getProperty "kiuwan.port.front5" $GLOBAL_CONFIG_PATH)
	if [ -z "$PORT_8543_NUMBER" ]
	then
		PORT_8543_NUMBER=8543
	fi
	PORT_8543=$(checkPortIsNotUsed $PORT_8543_NUMBER)
	printPortAvailable $PORT_8543 $PORT_8543_NUMBER "Kiuwan front 5"

	PORT_8643_NUMBER=$(getProperty "kiuwan.port.front6" $GLOBAL_CONFIG_PATH)
	if [ -z "$PORT_8643_NUMBER" ]
	then
		PORT_8643_NUMBER=8643
	fi
	PORT_8643=$(checkPortIsNotUsed $PORT_8643_NUMBER)
	printPortAvailable $PORT_8643 $PORT_8643_NUMBER "Kiuwan front 6"

	PORT_8743_NUMBER=$(getProperty "kiuwan.port.front7" $GLOBAL_CONFIG_PATH)
	if [ -z "$PORT_8743_NUMBER" ]
	then
		PORT_8743_NUMBER=8743
	fi
	PORT_8743=$(checkPortIsNotUsed $PORT_8743_NUMBER)
	printPortAvailable $PORT_8743 $PORT_8743_NUMBER "Kiuwan front 7"

	PORT_8843_NUMBER=$(getProperty "kiuwan.port.front8" $GLOBAL_CONFIG_PATH)
	if [ -z "$PORT_8843_NUMBER" ]
	then
		PORT_8843_NUMBER=8843
	fi
	PORT_8843=$(checkPortIsNotUsed $PORT_8843_NUMBER)
	printPortAvailable $PORT_8843 $PORT_8843_NUMBER "Kiuwan front 8"
fi
echo "" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
echo "Checking commands" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
echo "-----------------" 2>&1 | tee -a $LOG_FILE_PREREQUISITES

COMMAND_DOCKER="docker"
COMMAND_DOCKER_EXISTS=$(checkCommandExists $COMMAND_DOCKER)
printCommandAvailable $COMMAND_DOCKER_EXISTS $COMMAND_DOCKER

COMMAND_DOCKER_COMPOSE="docker-compose"
COMMAND_DOCKER_COMPOSE_EXISTS=$(checkCommandExists $COMMAND_DOCKER_COMPOSE)
printCommandAvailable $COMMAND_DOCKER_COMPOSE_EXISTS $COMMAND_DOCKER_COMPOSE

COMMAND_OPENSSL="openssl"
COMMAND_OPENSSL_EXISTS=$(checkCommandExists $COMMAND_OPENSSL)
printCommandAvailable $COMMAND_OPENSSL_EXISTS $COMMAND_OPENSSL

COMMAND_UNZIP="unzip"
COMMAND_UNZIP_EXISTS=$(checkCommandExists $COMMAND_UNZIP)
printCommandAvailable $COMMAND_UNZIP_EXISTS $COMMAND_UNZIP

COMMAND_TEE="tee"
COMMAND_TEE_EXISTS=$(checkCommandExists $COMMAND_TEE)
printCommandAvailable $COMMAND_TEE_EXISTS $COMMAND_TEE

COMMAND_JAVA="java"
COMMAND_JAVA_EXISTS=$(checkCommandExists $COMMAND_JAVA)
printCommandAvailable $COMMAND_JAVA_EXISTS $COMMAND_JAVA

COMMAND_BC="bc"
COMMAND_BC_EXISTS=$(checkCommandExists $COMMAND_BC)
printCommandAvailable $COMMAND_BC_EXISTS $COMMAND_BC

COMMAND_WGET="wget"
COMMAND_WGET_EXISTS=$(checkCommandExists $COMMAND_WGET)
printCommandAvailable $COMMAND_WGET_EXISTS $COMMAND_WGET

COMMAND_IP="ip"
COMMAND_IP_EXISTS=$(checkCommandExists $COMMAND_IP)
printCommandAvailable $COMMAND_IP_EXISTS $COMMAND_IP

NEED_CHECK_REMOTE_CONNECTIONS="false"
if [[ $IS_UPDATE_CLIENTS == "true" ]]
then
	if [[ $UPDATE_CLIENTS_FLAG == "true" ]]
	then
		NEED_CHECK_REMOTE_CONNECTIONS="true"
	else
		NEED_CHECK_REMOTE_CONNECTIONS="false"
	fi
else
	NEED_CHECK_REMOTE_CONNECTIONS="true"
fi
if [[ $NEED_CHECK_REMOTE_CONNECTIONS == "true" ]]
then
echo "" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
		echo "Checking connections" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
		echo "--------------------" 2>&1 | tee -a $LOG_FILE_PREREQUISITES


    if [ "$COMMAND_WGET_EXISTS" -eq "0" ]; then
			CONNECTION_KIUWAN_AVAILABLE=$(checkUrlconnectivity "https://static.kiuwan.com/download/onpremise/compatibility.version")
			if [ "$CONNECTION_KIUWAN_AVAILABLE" -eq "0" ]; then
			  echo -e "[\e[92m OK \e[0m] Kiuwan" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
			else
				echo -e "[\e[91mFAIL\e[0m] Kiuwan" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
				KOP_POSSIBLE_ERROR_ON_INSTALL="1"
			fi
		else
			echo -e "[\e[91mFAIL\e[0m] Kiuwan: Cannot check connections since no $COMMAND_WGET is installed" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
			KOP_POSSIBLE_ERROR_ON_INSTALL="1"
		fi
		if [ "$COMMAND_DOCKER_EXISTS" -eq "0" ]; then
			CONNECTION_DOCKER_AVAILABLE=$(checkDockerconnectivity "hello-world")
			if [ "$CONNECTION_DOCKER_AVAILABLE" -eq "0" ]; then
			  echo -e "[\e[92m OK \e[0m] Docker" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
			else
				echo -e "[\e[91mFAIL\e[0m] Docker" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
				KOP_POSSIBLE_ERROR_ON_INSTALL="1"
			fi
		else
			echo -e "[\e[91mFAIL\e[0m] $COMMAND_DOCKER not found" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
			KOP_POSSIBLE_ERROR_ON_INSTALL="1"
		fi



fi
if [[ $IS_UPDATE == "false" ]]
then
	echo "" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
	echo "Checking docker network" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
	echo "-----------------------" 2>&1 | tee -a $LOG_FILE_PREREQUISITES

	if [ "$COMMAND_DOCKER_EXISTS" -eq "0" ]; then
		NETWORKS_MATCH=$(docker network inspect $(docker network ls -f driver=bridge --format {{.ID}}) -f '{{json .IPAM.Config}}' | grep 172.172.0.0)
		if [ -z $NETWORKS_MATCH ]; then
		  echo -e "[\e[92m OK \e[0m] 172.172.0.0/16 (bridge)" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
		else
			echo -e "[\e[91mFAIL\e[0m] 172.172.0.0/16 is NOT available" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
			KOP_POSSIBLE_ERROR_ON_INSTALL="1"
		fi
	else
		echo -e "[\e[91mFAIL\e[0m] $COMMAND_DOCKER not found" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
		KOP_POSSIBLE_ERROR_ON_INSTALL="1"
	fi
fi
echo "" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
echo "Checking tool versions" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
echo "----------------------" 2>&1 | tee -a $LOG_FILE_PREREQUISITES

if [ "$COMMAND_DOCKER_EXISTS" -eq "0" ]; then
	COMMAND_DOCKER_VERSION="docker --version"
	COMMAND_DOCKER_VERSION_OUTPUT=`$COMMAND_DOCKER_VERSION`
	DOCKER_VERSION_NUMBER=$(getVersionNumber "$COMMAND_DOCKER_VERSION_OUTPUT")
	printCommandVersion "docker" "$DOCKER_VERSION_NUMBER" "19.03.2"
fi

if [ "$COMMAND_DOCKER_COMPOSE_EXISTS" -eq "0" ]; then
	COMMAND_DOCKER_COMPOSE_VERSION="docker-compose -version"
	COMMAND_DOCKER_COMPOSE_VERSION_OUTPUT=`$COMMAND_DOCKER_COMPOSE_VERSION`
	DOCKER_COMPOSE_VERSION_NUMBER=$(getVersionNumber "$COMMAND_DOCKER_COMPOSE_VERSION_OUTPUT")
	printCommandVersion "docker-compose" "$DOCKER_COMPOSE_VERSION_NUMBER" "1.24.1"
fi

if [ "$COMMAND_OPENSSL_EXISTS" -eq "0" ]; then
	COMMAND_OPENSSL_VERSION="openssl version"
	COMMAND_OPENSSL_VERSION_OUTPUT=`$COMMAND_OPENSSL_VERSION`
	OPENSSL_VERSION_NUMBER=$(getVersionNumber "$COMMAND_OPENSSL_VERSION_OUTPUT")
	printCommandVersion "openssl" "$OPENSSL_VERSION_NUMBER" "1.0.2"
fi

if [ "$COMMAND_JAVA_EXISTS" -eq "0" ]; then
	COMMAND_JAVA_VERSION="echo $(java -version 2>&1)"
	COMMAND_JAVA_VERSION_OUTPUT=`$COMMAND_JAVA_VERSION`
	JAVA_VERSION_NUMBER=$(getVersionNumber "$COMMAND_JAVA_VERSION_OUTPUT")
	printCommandVersion "java" "$JAVA_VERSION_NUMBER" "1.8"
fi

echo "" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
echo "User Content Deployed" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
echo "---------------------" 2>&1 | tee -a $LOG_FILE_PREREQUISITES

PATH_CONFIG_SHARED_UPDATER_MYSQLCONNECTOR_MYSQLCONNECTOR_JAR="$CONFIG_SHARED_PATH/updater/mysqlConnector/mysql-connector-java-5.1.39-bin.jar"
EXISTS_CONFIG_SHARED_UPDATER_MYSQLCONNECTOR_MYSQLCONNECTOR_JAR=$(checkIfFileExist $PATH_CONFIG_SHARED_UPDATER_MYSQLCONNECTOR_MYSQLCONNECTOR_JAR)
printFileExists $EXISTS_CONFIG_SHARED_UPDATER_MYSQLCONNECTOR_MYSQLCONNECTOR_JAR "MySQL connector on Updater"

PATH_CONFIG_SHARED_KIUWAN_MYSQLCONNECTOR_MYSQLCONNECTOR_JAR="$CONFIG_SHARED_PATH/kiuwan/mysqlConnector/mysql-connector-java-5.1.39-bin.jar"
EXISTS_CONFIG_SHARED_KIUWAN_MYSQLCONNECTOR_MYSQLCONNECTOR_JAR=$(checkIfFileExist $PATH_CONFIG_SHARED_KIUWAN_MYSQLCONNECTOR_MYSQLCONNECTOR_JAR)
printFileExists $EXISTS_CONFIG_SHARED_KIUWAN_MYSQLCONNECTOR_MYSQLCONNECTOR_JAR "MySQL connector on Kiuwan"

PATH_CONFIG_SHARED_KIUWAN_LICENSE_LICENSE_PREM_LIC="$CONFIG_SHARED_PATH/kiuwan/license/license/prem.lic"
EXISTS_CONFIG_SHARED_KIUWAN_LICENSE_LICENSE_PREM_LIC=$(checkIfFileExist $PATH_CONFIG_SHARED_KIUWAN_LICENSE_LICENSE_PREM_LIC)
PATH_CONFIG_SHARED_KIUWAN_LICENSE_LICENSE_PREM_SIG="$CONFIG_SHARED_PATH/kiuwan/license/license/prem.sig"
EXISTS_CONFIG_SHARED_KIUWAN_LICENSE_LICENSE_PREM_SIG=$(checkIfFileExist $PATH_CONFIG_SHARED_KIUWAN_LICENSE_LICENSE_PREM_SIG)
EXISTS_CONFIG_SHARED_KIUWAN_LICENSE_LICENSE="false"

if [ "$EXISTS_CONFIG_SHARED_KIUWAN_LICENSE_LICENSE_PREM_LIC" == "true" ] && [ "$EXISTS_CONFIG_SHARED_KIUWAN_LICENSE_LICENSE_PREM_SIG" == "true" ]; then
	EXISTS_CONFIG_SHARED_KIUWAN_LICENSE_LICENSE="true"
fi
printFileExists $EXISTS_CONFIG_SHARED_KIUWAN_LICENSE_LICENSE "KIUWAN license"

PATH_CONFIG_SHARED_KIUWAN_LICENSE_CONFIGQ1_EXCEPTION="$CONFIG_SHARED_PATH/kiuwan/license/configq1/exception.q1"
EXISTS_CONFIG_SHARED_KIUWAN_LICENSE_CONFIGQ1_EXCEPTION=$(checkIfFileExist $PATH_CONFIG_SHARED_KIUWAN_LICENSE_CONFIGQ1_EXCEPTION)
PATH_CONFIG_SHARED_KIUWAN_LICENSE_CONFIGQ1_JOB="$CONFIG_SHARED_PATH/kiuwan/license/configq1/job.q1"
EXISTS_CONFIG_SHARED_KIUWAN_LICENSE_CONFIGQ1_JOB=$(checkIfFileExist $PATH_CONFIG_SHARED_KIUWAN_LICENSE_CONFIGQ1_JOB)
PATH_CONFIG_SHARED_KIUWAN_LICENSE_CONFIGQ1_MAIN="$CONFIG_SHARED_PATH/kiuwan/license/configq1/main.q1"
EXISTS_CONFIG_SHARED_KIUWAN_LICENSE_CONFIGQ1_MAIN=$(checkIfFileExist $PATH_CONFIG_SHARED_KIUWAN_LICENSE_CONFIGQ1_MAIN)
EXISTS_CONFIG_SHARED_KIUWAN_LICENSE_CONFIGQ1="false"

if [ "$EXISTS_CONFIG_SHARED_KIUWAN_LICENSE_CONFIGQ1_EXCEPTION" == "true" ] && [ "$EXISTS_CONFIG_SHARED_KIUWAN_LICENSE_CONFIGQ1_JOB" == "true" ] && [ "$EXISTS_CONFIG_SHARED_KIUWAN_LICENSE_CONFIGQ1_MAIN" == "true" ]; then
	EXISTS_CONFIG_SHARED_KIUWAN_LICENSE_CONFIGQ1="true"
fi
printFileExists $EXISTS_CONFIG_SHARED_KIUWAN_LICENSE_CONFIGQ1 "KIUWAN license configq1"

PATH_CONFIG_SHARED_MYSQL_CERTS_CACERT_PEM="$CONFIG_SHARED_PATH/MySql/certs/cacert.pem"
EXISTS_CONFIG_SHARED_MYSQL_CERTS_CACERT_PEM=$(checkIfFileExist $PATH_CONFIG_SHARED_MYSQL_CERTS_CACERT_PEM)
printFileExists $EXISTS_CONFIG_SHARED_MYSQL_CERTS_CACERT_PEM "CA cert on MySQL"

PATH_CONFIG_SHARED_MYSQL_CERTS_DOMAINCERT_PEM="$CONFIG_SHARED_PATH/MySql/certs/domaincert.pem"
EXISTS_CONFIG_SHARED_MYSQL_CERTS_DOMAINCERT_PEM=$(checkIfFileExist $PATH_CONFIG_SHARED_MYSQL_CERTS_DOMAINCERT_PEM)
printFileExists $EXISTS_CONFIG_SHARED_MYSQL_CERTS_DOMAINCERT_PEM "Public key on MySQL"

PATH_CONFIG_SHARED_MYSQL_CERTS_DOMAINKEY_PEM="$CONFIG_SHARED_PATH/MySql/certs/domainkey.pem"
EXISTS_CONFIG_SHARED_MYSQL_CERTS_DOMAINKEY_PEM=$(checkIfFileExist $PATH_CONFIG_SHARED_MYSQL_CERTS_DOMAINKEY_PEM)
printFileExists $EXISTS_CONFIG_SHARED_MYSQL_CERTS_DOMAINKEY_PEM "Private key on MySQL"

PATH_CONFIG_SHARED_UPDATER_CACERRT_CACERT_PEM="$CONFIG_SHARED_PATH/updater/caCert/cacert.pem"
EXISTS_CONFIG_SHARED_UPDATER_CACERRT_CACERT_PEM=$(checkIfFileExist $PATH_CONFIG_SHARED_UPDATER_CACERRT_CACERT_PEM)
printFileExists $EXISTS_CONFIG_SHARED_UPDATER_CACERRT_CACERT_PEM "CA cert on Updater"

PATH_CONFIG_SHARED_APACHELOADBALANCER_CERTS_DOMAINCERT_PEM="$CONFIG_SHARED_PATH/ApacheLoadBalancer/certs/domaincert.pem"
EXISTS_CONFIG_SHARED_APACHELOADBALANCER_CERTS_DOMAINCERT_PEM=$(checkIfFileExist $PATH_CONFIG_SHARED_APACHELOADBALANCER_CERTS_DOMAINCERT_PEM)
printFileExists $EXISTS_CONFIG_SHARED_APACHELOADBALANCER_CERTS_DOMAINCERT_PEM "Public key on Apache load balancer"

PATH_CONFIG_SHARED_APACHELOADBALANCER_CERTS_DOMAINKEY_PEM="$CONFIG_SHARED_PATH/ApacheLoadBalancer/certs/domainkey.pem"
EXISTS_CONFIG_SHARED_APACHELOADBALANCER_CERTS_DOMAINKEY_PEM=$(checkIfFileExist $PATH_CONFIG_SHARED_APACHELOADBALANCER_CERTS_DOMAINKEY_PEM)
printFileExists $EXISTS_CONFIG_SHARED_APACHELOADBALANCER_CERTS_DOMAINKEY_PEM "Private key on Apache load balancer"

PATH_CONFIG_SHARED_APACHELOADBALANCER_CERTS_CACERT_PEM="$CONFIG_SHARED_PATH/ApacheLoadBalancer/certs/cacert.pem"
EXISTS_CONFIG_SHARED_APACHELOADBALANCER_CERTS_CACERT_PEM=$(checkIfFileExist $PATH_CONFIG_SHARED_APACHELOADBALANCER_CERTS_CACERT_PEM)
printFileExists $EXISTS_CONFIG_SHARED_APACHELOADBALANCER_CERTS_CACERT_PEM "CA cert on Apache load balancer"


PATH_CONFIG_SHARED_KIUWAN_KEYSTORE_KEYSTORE_JKS="$CONFIG_SHARED_PATH/kiuwan/keystore/domainkeystore.jks"
EXISTS_CONFIG_SHARED_KIUWAN_KEYSTORE_KEYSTORE_JKS=$(checkIfFileExist $PATH_CONFIG_SHARED_KIUWAN_KEYSTORE_KEYSTORE_JKS)
printFileExists $EXISTS_CONFIG_SHARED_KIUWAN_KEYSTORE_KEYSTORE_JKS "Keystore on kiuwan"

PATH_CONFIG_SHARED_KIUWAN_KEYSTORE_TRUSTSTORE_JKS="$CONFIG_SHARED_PATH/kiuwan/keystore/truststore.jks"
EXISTS_CONFIG_SHARED_KIUWAN_KEYSTORE_TRUSTSTORE_JKS=$(checkIfFileExist $PATH_CONFIG_SHARED_KIUWAN_KEYSTORE_TRUSTSTORE_JKS)
printFileExists $EXISTS_CONFIG_SHARED_KIUWAN_KEYSTORE_TRUSTSTORE_JKS "Truststore on kiuwan"

PATH_CONFIG_SHARED_UPDATER_KEYSTORE_KEYSTORE_JKS="$CONFIG_SHARED_PATH/updater/keystore/domainkeystore.jks"
EXISTS_CONFIG_SHARED_UPDATER_KEYSTORE_KEYSTORE_JKS=$(checkIfFileExist $PATH_CONFIG_SHARED_UPDATER_KEYSTORE_KEYSTORE_JKS)
printFileExists $EXISTS_CONFIG_SHARED_UPDATER_KEYSTORE_KEYSTORE_JKS "Keystore on updater"

PATH_CONFIG_SHARED_UPDATER_KEYSTORE_TRUSTSTORE_JKS="$CONFIG_SHARED_PATH/updater/keystore/truststore.jks"
EXISTS_CONFIG_SHARED_UPDATER_KEYSTORE_TRUSTSTORE_JKS=$(checkIfFileExist $PATH_CONFIG_SHARED_UPDATER_KEYSTORE_TRUSTSTORE_JKS)
printFileExists $EXISTS_CONFIG_SHARED_UPDATER_KEYSTORE_TRUSTSTORE_JKS "Truststore on updater"

echo "" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
echo "System information" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
echo "------------------" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
echo "OS details: $(uname -a)"

if [ "$COMMAND_BC_EXISTS" -eq "0" ]; then
	MEM_AVAILABLE=$(getFreeMemAvailable)
	echo "Free memory: $MEM_AVAILABLE GB" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
else
	echo "Free memory: Check not available. Install $COMMAND_BC." 2>&1 | tee -a $LOG_FILE_PREREQUISITES
fi



if [ -d $CONFIG_SHARED_PATH ]
then
	STORAGE_AVAILABLE_CONFIG_SHARED=$(getFreeSpaceAvailableInDirectory $CONFIG_SHARED_PATH)
  echo "Free Storage in config-shared volume: $STORAGE_AVAILABLE_CONFIG_SHARED" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
else
  echo -e "\e[101mconfig-shared volume directory $CONFIG_SHARED_PATH does not exist. - deploy-volumes.sh not run?\e[49m"  2>&1 | tee -a $LOG_FILE_PREREQUISITES
fi

if [ -d $DATA_SHARED_PATH ]
then
	STORAGE_AVAILABLE_DATA_SHARED=$(getFreeSpaceAvailableInDirectory $DATA_SHARED_PATH)
	echo "Free Storage in data-shared volume: $STORAGE_AVAILABLE_DATA_SHARED" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
else
  echo -e "\e[101mdata-shared volume directory $DATA_SHARED_PATH does not exist. - deploy-volumes.sh not run?\e[49m"  2>&1 | tee -a $LOG_FILE_PREREQUISITES
fi

if [ -d $DATA_LOCAL_PATH ]
then
	STORAGE_AVAILABLE_DATA_LOCAL=$(getFreeSpaceAvailableInDirectory $DATA_LOCAL_PATH)
	echo "Free Storage in data-local volume: $STORAGE_AVAILABLE_DATA_LOCAL" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
else
  echo -e "\e[101mdata-local volume directory $DATA_LOCAL_PATH does not exist. - deploy-volumes.sh not run?\e[49m"  2>&1 | tee -a $LOG_FILE_PREREQUISITES
fi

if [ "$COMMAND_DOCKER_EXISTS" -eq "0" ]; then
	DOCKER_PATH_VOLUME=$(docker info -f '{{json .DockerRootDir}}')
	DOCKER_PATH_VOLUME=${DOCKER_PATH_VOLUME//\"/}

	if [ -d $DOCKER_PATH_VOLUME ]
	then
		STORAGE_AVAILABLE_DOCKER_VOLUME=$(getFreeSpaceAvailableInDirectory $DOCKER_PATH_VOLUME)
		echo "Free Storage in Docker volume: $STORAGE_AVAILABLE_DOCKER_VOLUME" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
	else
	  echo -e "\e[101mdocker directory $DOCKER_PATH_VOLUME does not exist."  2>&1 | tee -a $LOG_FILE_PREREQUISITES
	fi
else
	echo -e "[\e[91mFAIL\e[0m] $COMMAND_DOCKER not found" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
fi


echo "" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
echo "Docker filesystem type" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
echo "----------------------" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
if [ "$COMMAND_DOCKER_EXISTS" -eq "0" ]; then

	if [ -d $DOCKER_PATH_VOLUME ]
	then
		FILESYSTEMTYPE=$(getFileSystemType $DOCKER_PATH_VOLUME)

		echo "Docker filesystem type: $FILESYSTEMTYPE" 2>&1 | tee -a $LOG_FILE_PREREQUISITES

		if [ "$FILESYSTEMTYPE" == "xfs" ]; then
			DTYPE=$(getSupportDType)

			if [ "$DTYPE" -eq "0" ]; then
				echo -e "[\e[92m OK \e[0m] Docker filesystem supports d_type" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
			else
				echo -e "[\e[91mFAIL\e[0m] Docker filesystem supports d_type" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
				KOP_POSSIBLE_ERROR_ON_INSTALL="1"
			fi
			COMMAND_XFSINFO="xfs_info"
			COMMAND_XFSINFO_EXISTS=$(checkCommandExists $COMMAND_XFSINFO)
			printCommandAvailable $COMMAND_XFSINFO_EXISTS $COMMAND_XFSINFO
			if [ "$COMMAND_XFSINFO_EXISTS" -eq "0" ]; then
				FTYPESUPPORT=$(getFtypeXFSSupport $DOCKER_PATH_VOLUME)
				if [ "$FTYPESUPPORT" -eq "1" ]; then
					echo -e "[\e[92m OK \e[0m] Docker XFS filesystem ftype=1" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
				else
					echo -e "[\e[91mFAIL\e[0m] Docker XFS filesystem ftype=0" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
					KOP_POSSIBLE_ERROR_ON_INSTALL="1"
				fi
			fi
		fi
	else
	  echo -e "\e[101mdocker directory $DOCKER_PATH_VOLUME does not exist."  2>&1 | tee -a $LOG_FILE_PREREQUISITES
	fi
else
	echo -e "[\e[91mFAIL\e[0m] $COMMAND_DOCKER not found" 2>&1 | tee -a $LOG_FILE_PREREQUISITES
fi


cd $CURRENTDIR
echo ""
echo ""
if [ "$KOP_POSSIBLE_ERROR_ON_INSTALL" -eq "1" ]; then
	echo "********************** WARNING ****************************"
	echo "Some requirements are not met"
	echo "Please refer to the following documentation URL:"
	echo "https://www.kiuwan.com/docs/display/K5/Kiuwan+On-Premises+Distributed+Installation+Guide#KiuwanOn-PremisesDistributedInstallationGuide-Systemrequirements"
	echo "***********************************************************"
else
	if [[ $IS_UPDATE == "false" ]]
	then
		echo "******************* ALL SYSTEMS CHECKS OK *****************"
		echo "All minimum requirements are met. You can proceed with your"
		echo "installation, but take into account that this tool does not"
		echo "check for free memory or storage."
		echo "It is up to you to reserve enough memory and storage to"
		echo "meet your needs. For more information check:"
		echo "https://www.kiuwan.com/docs/display/K5/Kiuwan+On-Premises+Distributed+Installation+Guide#KiuwanOn-PremisesDistributedInstallationGuide-Systemrequirements"
		echo "***********************************************************"
	else
		echo "******************* ALL SYSTEMS CHECKS OK *****************"
		echo "All minimum requirements are met. You can proceed with your"
		echo "update, but take into account that this tool does not"
		echo "check for free memory or storage."
		echo "It is up to you to reserve enough memory and storage to"
		echo "meet your needs. For more information check:"
		echo "https://www.kiuwan.com/docs/display/K5/Kiuwan+On-Premises+Distributed+Installation+Guide#KiuwanOn-PremisesDistributedInstallationGuide-Systemrequirements"
		echo "***********************************************************"
	fi
fi
echo ""
echo ""
