#!/bin/bash
source ./tools/functions.sh
checkRoot
PARAMETER=$1
DEPLOY_CERTS="false"
DEPLOY_LICENSE="false"
if [ -z "$PARAMETER" ]
then
  echo "Trying to deploy all user content"
  DEPLOY_CERTS="true"
  DEPLOY_LICENSE="true"
else
  if [ "$PARAMETER" == "license" ]
  then
    echo "Trying to deploy license"
    DEPLOY_LICENSE="true"
  else
    if [ "$PARAMETER" == "certs" ]
    then
      echo "Trying to deploy certs"
      DEPLOY_CERTS="true"
    else
      echo "BAD PARAMETER"
      exit 1
    fi
  fi
fi

VOLUMES_PROPERTIES_FILE="./config/volumes.properties"
CONFIG_SHARED_PATH=$(getProperty "config.shared" $VOLUMES_PROPERTIES_FILE)

user_content_dir=./user-content
user_content_certs_dir=${user_content_dir}/certs

# Source filenames
ca_crt_file=cacert.pem
crt_file=domaincert.pem
key_file=domainkey.pem
jks_file=domainkeystore.jks
truststore_file=truststore.jks
mysqlconnector_file=mysql-connector-java-5.1.39-bin.jar
license_configq1_file=configq1.zip
license_license_file=license.zip

# Check folders and files
abortIfDirNotFound "${CONFIG_SHARED_PATH}"
if [ "$DEPLOY_CERTS" == "true" ]
then
  abortIfNotFound "${user_content_certs_dir}/${ca_crt_file}"
  abortIfNotFound "${user_content_certs_dir}/${crt_file}"
  abortIfNotFound "${user_content_certs_dir}/${key_file}"
  abortIfNotFound "${user_content_certs_dir}/${jks_file}"
  abortIfNotFound "${user_content_certs_dir}/${truststore_file}"
fi

abortIfNotFound "${user_content_dir}/${mysqlconnector_file}"
if [ "$DEPLOY_LICENSE" == "true" ]
then
  abortIfNotFound "${user_content_dir}/${license_configq1_file}"
  abortIfNotFound "${user_content_dir}/${license_license_file}"
fi

# Destination folders (certificates)
apache_certs=${CONFIG_SHARED_PATH}/ApacheLoadBalancer/certs
mysql_certs=${CONFIG_SHARED_PATH}/MySql/certs
kiuwan_keystore=${CONFIG_SHARED_PATH}/kiuwan/keystore
updater_certs=${CONFIG_SHARED_PATH}/updater/caCert
updater_keystore=${CONFIG_SHARED_PATH}/updater/keystore

# Destination folders (MySQL connector)
kiuwan_mysqlconnector_dir=${CONFIG_SHARED_PATH}/kiuwan/mysqlConnector
updater_mysqlconnector_dir=${CONFIG_SHARED_PATH}/updater/mysqlConnector

# Destination folder (license)
kiuwan_license_configq1_dir=${CONFIG_SHARED_PATH}/kiuwan/license/configq1
kiuwan_license_license_dir=${CONFIG_SHARED_PATH}/kiuwan/license/license

# Copy to CONFIG_SHARED_PATH
if [ "$DEPLOY_CERTS" == "true" ]
then
  echo "Copying files for Apache..."
  cp -vf ${user_content_certs_dir}/${ca_crt_file} ${apache_certs}
  cp -vf ${user_content_certs_dir}/${crt_file} ${apache_certs}
  cp -vf ${user_content_certs_dir}/${key_file} ${apache_certs}

  echo "Copying files for MySQL..."
  cp -vf ${user_content_certs_dir}/${ca_crt_file} ${mysql_certs}
  cp -vf ${user_content_certs_dir}/${crt_file} ${mysql_certs}
  cp -vf ${user_content_certs_dir}/${key_file} ${mysql_certs}

  echo "Copying files for Kiuwan..."
  cp -vf ${user_content_certs_dir}/${jks_file} ${kiuwan_keystore}
  cp -vf ${user_content_certs_dir}/${truststore_file} ${kiuwan_keystore}

  echo "Copying files for Updater..."
  cp -vf ${user_content_certs_dir}/${ca_crt_file} ${updater_certs}
  cp -vf ${user_content_certs_dir}/${jks_file} ${updater_keystore}
  cp -vf ${user_content_certs_dir}/${truststore_file} ${updater_keystore}
fi


echo "Copying MySQL connector..."
cp -vf ${user_content_dir}/${mysqlconnector_file} ${kiuwan_mysqlconnector_dir}
cp -vf ${user_content_dir}/${mysqlconnector_file} ${updater_mysqlconnector_dir}

if [ "$DEPLOY_LICENSE" == "true" ]
then
  echo "Extracting license..."
  rm -rf ${kiuwan_license_configq1_dir}
  rm -rf ${kiuwan_license_license_dir}
  unzip ${user_content_dir}/${license_configq1_file} -d ${kiuwan_license_configq1_dir}
  unzip ${user_content_dir}/${license_license_file} -d ${kiuwan_license_license_dir}
fi


echo "Setting permissions..."
if [ $DEPLOY_CERTS == "true" ]
then
  chmod 775 ${apache_certs}/${ca_crt_file}
  chmod 775 ${apache_certs}/${crt_file}
  chmod 775 ${apache_certs}/${key_file}

  chmod 775 ${mysql_certs}/${ca_crt_file}
  chmod 775 ${mysql_certs}/${crt_file}
  chmod 775 ${mysql_certs}/${key_file}

  chmod 775 ${kiuwan_keystore}/${jks_file}
  chmod 775 ${kiuwan_keystore}/${truststore_file}

  chmod 775 ${updater_certs}/${ca_crt_file}
  chmod 775 ${updater_keystore}/${jks_file}
  chmod 775 ${updater_keystore}/${truststore_file}
fi

chmod 775 ${kiuwan_mysqlconnector_dir}/${mysqlconnector_file}
chmod 775 ${updater_mysqlconnector_dir}/${mysqlconnector_file}

if [ $DEPLOY_LICENSE == "true" ]
then
  chmod -R 775 ${kiuwan_license_configq1_dir}
  chmod -R 775 ${kiuwan_license_license_dir}
fi

echo Done!
