#!/bin/bash
source ../tools/functions.sh
checkRoot
source ../tools/check-permissions.sh

VOLUMES_PROPERTIES_FILE="../config/volumes.properties"
DATA_LOCAL_PATH=$(getProperty "data.local" $VOLUMES_PROPERTIES_FILE)
CONFIG_SHARED_PATH=$(getProperty "config.shared" $VOLUMES_PROPERTIES_FILE)

abortIfDirNotFound "${DATA_LOCAL_PATH}"
abortIfDirNotFound "${CONFIG_SHARED_PATH}"

LOG_FILE="../logs/install-infrastructure.log"

CURRENT_UID=$(getCurrentUid)
HOST_IP=$(getHostIp)
GLOBAL_CONFIG_FILE=$CONFIG_SHARED_PATH/globalConfig/globalConfig.properties
EXTERNALIZE_REDIS_CACHE=$(getProperty "kiuwan.externalize.redis.cache" $GLOBAL_CONFIG_FILE)
EXTERNALIZE_REDIS_STORAGE=$(getProperty "kiuwan.externalize.redis.storage" $GLOBAL_CONFIG_FILE)

if [[ $EXTERNALIZE_REDIS_CACHE == "true" ]] || [[ $EXTERNALIZE_REDIS_STORAGE == "true" ]]
then
  echo "Redis is externalized"
else
  DATA_LOCAL_PATH=$DATA_LOCAL_PATH \
  CONFIG_SHARED_PATH=$CONFIG_SHARED_PATH \
  CURRENT_UID=$CURRENT_UID \
  HOST_IP=$HOST_IP \
  docker-compose -f ./compose/install-infrastructure.yml -p kiuwan up --abort-on-container-exit 2>&1 | tee -a $LOG_FILE
  
  DATA_LOCAL_PATH=$DATA_LOCAL_PATH \
  CONFIG_SHARED_PATH=$CONFIG_SHARED_PATH \
  CURRENT_UID=$CURRENT_UID \
  HOST_IP=$HOST_IP \
  docker-compose -f ./compose/install-infrastructure.yml -p kiuwan down 2>&1 | tee -a $LOG_FILE
fi
docker info 2>&1 >> $LOG_FILE
