#!/bin/bash
source ../tools/functions.sh
checkRoot
source ../tools/check-permissions.sh

MANUAL_SERVICE_INDICATED=$1

VOLUMES_PROPERTIES_FILE="../config/volumes.properties"
DATA_LOCAL_PATH=$(getProperty "data.local" $VOLUMES_PROPERTIES_FILE)
CONFIG_SHARED_PATH=$(getProperty "config.shared" $VOLUMES_PROPERTIES_FILE)

abortIfDirNotFound "${DATA_LOCAL_PATH}"
abortIfDirNotFound "${CONFIG_SHARED_PATH}"

CURRENT_UID=$(getCurrentUid)
HOST_IP=$(getHostIp)
GLOBAL_CONFIG_FILE=$CONFIG_SHARED_PATH/globalConfig/globalConfig.properties
EXTERNALIZE_APACHELOADBALANCER=$(getProperty "kiuwan.externalize.apacheloadbalancer" $GLOBAL_CONFIG_FILE)
EXTERNALIZE_REDIS_CACHE=$(getProperty "kiuwan.externalize.redis.cache" $GLOBAL_CONFIG_FILE)
EXTERNALIZE_REDIS_STORAGE=$(getProperty "kiuwan.externalize.redis.storage" $GLOBAL_CONFIG_FILE)
EXTERNALIZE_MYSQL=$(getProperty "kiuwan.externalize.mysql" $GLOBAL_CONFIG_FILE)
KIUWAN_CLUSTER_MODE=$(getProperty "kiuwan.externalize.clustermode" $GLOBAL_CONFIG_FILE)

PORTMYSQL=$(getProperty "kiuwan.port.mysql" $GLOBAL_CONFIG_FILE)
PORTAPACHEHTTP=$(getProperty "kiuwan.port.apache.http" $GLOBAL_CONFIG_FILE)
PORTAPACHEHTTPS=$(getProperty "kiuwan.port.apache.https" $GLOBAL_CONFIG_FILE)

MYSQLUSER=$(getProperty "mysql.username" $GLOBAL_CONFIG_FILE)
MYSQLPASS=$(getProperty "mysql.password" $GLOBAL_CONFIG_FILE)
LOG_FILE="../logs/start-infrastructure.log"

startApache() {
  PORTMYSQL=$PORTMYSQL \
  PORTAPACHEHTTP=$PORTAPACHEHTTP \
  PORTAPACHEHTTPS=$PORTAPACHEHTTPS \
  DATA_LOCAL_PATH=$DATA_LOCAL_PATH \
  CONFIG_SHARED_PATH=$CONFIG_SHARED_PATH \
  CURRENT_UID=$CURRENT_UID \
  HOST_IP=$HOST_IP \
  docker-compose -f ./compose/infrastructure.yml -p kiuwan up -d apacheloadbalancer 2>&1 | tee -a $LOG_FILE
}

startRedis() {
  PORTMYSQL=$PORTMYSQL \
  PORTAPACHEHTTP=$PORTAPACHEHTTP \
  PORTAPACHEHTTPS=$PORTAPACHEHTTPS \
  DATA_LOCAL_PATH=$DATA_LOCAL_PATH \
  CONFIG_SHARED_PATH=$CONFIG_SHARED_PATH \
  CURRENT_UID=$CURRENT_UID \
  HOST_IP=$HOST_IP \
  docker-compose -f ./compose/infrastructure.yml -p kiuwan up -d redis_00001 redis_00002 redis_00003 redis_00004 redis_00005 redis_00006 2>&1 | tee -a $LOG_FILE
}

startMySQL() {
  PORTMYSQL=$PORTMYSQL \
  PORTAPACHEHTTP=$PORTAPACHEHTTP \
  PORTAPACHEHTTPS=$PORTAPACHEHTTPS \
  DATA_LOCAL_PATH=$DATA_LOCAL_PATH \
  CONFIG_SHARED_PATH=$CONFIG_SHARED_PATH \
  CURRENT_UID=$CURRENT_UID \
  HOST_IP=$HOST_IP \
  docker-compose -f ./compose/infrastructure.yml -p kiuwan up -d mysqlkiuwan 2>&1 | tee -a $LOG_FILE
}

startManual() {
  PORTMYSQL=$PORTMYSQL \
  PORTAPACHEHTTP=$PORTAPACHEHTTP \
  PORTAPACHEHTTPS=$PORTAPACHEHTTPS \
  DATA_LOCAL_PATH=$DATA_LOCAL_PATH \
  CONFIG_SHARED_PATH=$CONFIG_SHARED_PATH \
  CURRENT_UID=$CURRENT_UID \
  HOST_IP=$HOST_IP \
  docker-compose -f ./compose/infrastructure.yml -p kiuwan up --no-deps -d $MANUAL_SERVICE_INDICATED 2>&1 | tee -a $LOG_FILE
}

if [ -n "$MANUAL_SERVICE_INDICATED" ]
then
  if [[ $MANUAL_SERVICE_INDICATED == "redis" ]]
  then
    startRedis
  else
    NO_SERVICE_NEEDED="false"
    if [[ $KIUWAN_CLUSTER_MODE == "false" ]]
    then

      if [[ $EXTERNALIZE_REDIS_CACHE == "true" ]] || [[ $EXTERNALIZE_REDIS_STORAGE == "true" ]]
      then
        if [[ $MANUAL_SERVICE_INDICATED == "redis" ]]
        then
          NO_SERVICE_NEEDED="true"
          echo "redis is externalized"
        fi
      fi

      if [[ $EXTERNALIZE_APACHELOADBALANCER == "true" ]]
      then
        if [[ $MANUAL_SERVICE_INDICATED == "apacheloadbalancer" ]]
        then
          NO_SERVICE_NEEDED="true"
          echo "apacheloadbalancer is externalized"
        fi
      fi

      if [[ $EXTERNALIZE_MYSQL == "true" ]]
      then
        if [[ $MANUAL_SERVICE_INDICATED == "mysqlkiuwan" ]]
        then
          NO_SERVICE_NEEDED="true"
          echo "mysqlkiuwan is externalized"
        fi
      fi

      if [[ $NO_SERVICE_NEEDED == "true" ]]
      then
        echo "No service will start"
      else
        startManual
      fi
    fi
  fi
else
  if [[ $EXTERNALIZE_REDIS_CACHE == "true" ]] || [[ $EXTERNALIZE_REDIS_STORAGE == "true" ]]
  then
    echo "Redis is externalized"
  else
    startRedis
  fi

  if [[ $EXTERNALIZE_APACHELOADBALANCER == "true" ]]
  then
    echo "ApacheLoadBalancer is externalized"
  else
    startApache
  fi

  if [[ $EXTERNALIZE_MYSQL == "true" ]]
  then
    echo "MySQL is externalized"
  else
    if [ -f $CONFIG_SHARED_PATH/MySql/initScriptsOrigin/0002_mysql_user.sql.tpl ];
    then
      configureMySqlUserAndPass "$CONFIG_SHARED_PATH/MySql/initScriptsOrigin/0002_mysql_user.sql.tpl" "$CONFIG_SHARED_PATH/MySql/initScripts/0002_mysql_user.sql" $MYSQLUSER $MYSQLPASS
    fi
    startMySQL
  fi
fi

