#!/bin/bash
source ../tools/functions.sh
checkRoot
source ../tools/check-permissions.sh

MANUAL_SERVICE_INDICATED=$1
VOLUMES_PROPERTIES_FILE="../config/volumes.properties"
DATA_LOCAL_PATH=$(getProperty "data.local" $VOLUMES_PROPERTIES_FILE)
DATA_SHARED_PATH=$(getProperty "data.shared" $VOLUMES_PROPERTIES_FILE)
CONFIG_SHARED_PATH=$(getProperty "config.shared" $VOLUMES_PROPERTIES_FILE)

abortIfDirNotFound "${DATA_LOCAL_PATH}"
abortIfDirNotFound "${DATA_SHARED_PATH}"
abortIfDirNotFound "${CONFIG_SHARED_PATH}"

GLOBAL_CONFIG_FILE_PATH="$CONFIG_SHARED_PATH/globalConfig/globalConfig.properties"

SINGLE_HOST_NODES_FRONT=$(getProperty "kiuwan.singlehost.nodes.front" $GLOBAL_CONFIG_FILE_PATH)
SINGLE_HOST_NODES_ANALYZERS=$(getProperty "kiuwan.singlehost.nodes.analyzers" $GLOBAL_CONFIG_FILE_PATH)
SINGLE_HOST_NODES_SCHEDULERS=$(getProperty "kiuwan.singlehost.nodes.schedulers" $GLOBAL_CONFIG_FILE_PATH)

SINGLE_HOST_NODES_FRONT_WITH_BLANK=${SINGLE_HOST_NODES_FRONT//,/ }
SINGLE_HOST_NODES_ANALYZERS_WITH_BLANK=${SINGLE_HOST_NODES_ANALYZERS//,/ }
SINGLE_HOST_NODES_SCHEDULERS_WITH_BLANK=${SINGLE_HOST_NODES_SCHEDULERS//,/ }

SINGLE_HOST_NODES=$SINGLE_HOST_NODES_FRONT_WITH_BLANK" "$SINGLE_HOST_NODES_ANALYZERS_WITH_BLANK" "$SINGLE_HOST_NODES_SCHEDULERS_WITH_BLANK

LOG_FILE="../logs/start-kiuwan.log"

CURRENT_UID=$(getCurrentUid)

KIUWANPORTFRONT1=$(getProperty "kiuwan.port.front1" $GLOBAL_CONFIG_FILE_PATH)
KIUWANPORTFRONT2=$(getProperty "kiuwan.port.front2" $GLOBAL_CONFIG_FILE_PATH)
KIUWANPORTFRONT3=$(getProperty "kiuwan.port.front3" $GLOBAL_CONFIG_FILE_PATH)
KIUWANPORTFRONT4=$(getProperty "kiuwan.port.front4" $GLOBAL_CONFIG_FILE_PATH)
KIUWANPORTFRONT5=$(getProperty "kiuwan.port.front5" $GLOBAL_CONFIG_FILE_PATH)
KIUWANPORTFRONT6=$(getProperty "kiuwan.port.front6" $GLOBAL_CONFIG_FILE_PATH)
KIUWANPORTFRONT7=$(getProperty "kiuwan.port.front7" $GLOBAL_CONFIG_FILE_PATH)
KIUWANPORTFRONT8=$(getProperty "kiuwan.port.front8" $GLOBAL_CONFIG_FILE_PATH)

if [ -n "$MANUAL_SERVICE_INDICATED" ]
then
  echo "You are going to start the service $MANUAL_SERVICE_INDICATED manually"
  KIUWANPORTFRONT1=$KIUWANPORTFRONT1 \
  KIUWANPORTFRONT2=$KIUWANPORTFRONT2 \
  KIUWANPORTFRONT3=$KIUWANPORTFRONT3 \
  KIUWANPORTFRONT4=$KIUWANPORTFRONT4 \
  KIUWANPORTFRONT5=$KIUWANPORTFRONT5 \
  KIUWANPORTFRONT6=$KIUWANPORTFRONT6 \
  KIUWANPORTFRONT7=$KIUWANPORTFRONT7 \
  KIUWANPORTFRONT8=$KIUWANPORTFRONT8 \
  DATA_LOCAL_PATH=$DATA_LOCAL_PATH \
  DATA_SHARED_PATH=$DATA_SHARED_PATH \
  CONFIG_SHARED_PATH=$CONFIG_SHARED_PATH \
  CURRENT_UID=$CURRENT_UID \
  docker-compose -f ./compose/kiuwan.yml up -d $MANUAL_SERVICE_INDICATED 2>&1 | tee -a $LOG_FILE
else
  KIUWANPORTFRONT1=$KIUWANPORTFRONT1 \
  KIUWANPORTFRONT2=$KIUWANPORTFRONT2 \
  KIUWANPORTFRONT3=$KIUWANPORTFRONT3 \
  KIUWANPORTFRONT4=$KIUWANPORTFRONT4 \
  KIUWANPORTFRONT5=$KIUWANPORTFRONT5 \
  KIUWANPORTFRONT6=$KIUWANPORTFRONT6 \
  KIUWANPORTFRONT7=$KIUWANPORTFRONT7 \
  KIUWANPORTFRONT8=$KIUWANPORTFRONT8 \
  DATA_LOCAL_PATH=$DATA_LOCAL_PATH \
  DATA_SHARED_PATH=$DATA_SHARED_PATH \
  CONFIG_SHARED_PATH=$CONFIG_SHARED_PATH \
  CURRENT_UID=$CURRENT_UID \
  docker-compose -f ./compose/kiuwan.yml up -d $SINGLE_HOST_NODES 2>&1 | tee -a $LOG_FILE
fi
