#!/bin/bash
source ../tools/functions.sh
checkRoot

MANUAL_SERVICE_INDICATED=$1
VOLUMES_PROPERTIES_FILE="../config/volumes.properties"
DATA_LOCAL_PATH=$(getProperty "data.local" $VOLUMES_PROPERTIES_FILE)
CONFIG_SHARED_PATH=$(getProperty "config.shared" $VOLUMES_PROPERTIES_FILE)

abortIfDirNotFound "${DATA_LOCAL_PATH}"
abortIfDirNotFound "${CONFIG_SHARED_PATH}"

CURRENT_UID=$(getCurrentUid)
HOST_IP=$(getHostIp)
GLOBAL_CONFIG_FILE=$CONFIG_SHARED_PATH/globalConfig/globalConfig.properties
EXTERNALIZE_APACHELOADBALANCER=$(getProperty "kiuwan.externalize.apacheloadbalancer" $GLOBAL_CONFIG_FILE)
EXTERNALIZE_REDIS_CACHE=$(getProperty "kiuwan.externalize.redis.cache" $GLOBAL_CONFIG_FILE)
EXTERNALIZE_REDIS_STORAGE=$(getProperty "kiuwan.externalize.redis.storage" $GLOBAL_CONFIG_FILE)
EXTERNALIZE_MYSQL=$(getProperty "kiuwan.externalize.mysql" $GLOBAL_CONFIG_FILE)

PORTMYSQL=$(getProperty "kiuwan.port.mysql" $GLOBAL_CONFIG_FILE)
PORTAPACHEHTTP=$(getProperty "kiuwan.port.apache.http" $GLOBAL_CONFIG_FILE)
PORTAPACHEHTTPS=$(getProperty "kiuwan.port.apache.https" $GLOBAL_CONFIG_FILE)

LOG_FILE="../logs/stop-infrastructure.log"

stopApache() {
  PORTMYSQL=$PORTMYSQL \
  PORTAPACHEHTTP=$PORTAPACHEHTTP \
  PORTAPACHEHTTPS=$PORTAPACHEHTTPS \
  DATA_LOCAL_PATH=$DATA_LOCAL_PATH \
  CONFIG_SHARED_PATH=$CONFIG_SHARED_PATH \
  CURRENT_UID=$CURRENT_UID \
  HOST_IP=$HOST_IP \
  docker-compose -f ./compose/infrastructure.yml -p kiuwan stop apacheloadbalancer 2>&1 | tee -a $LOG_FILE
}

stopRedis() {
  PORTMYSQL=$PORTMYSQL \
  PORTAPACHEHTTP=$PORTAPACHEHTTP \
  PORTAPACHEHTTPS=$PORTAPACHEHTTPS \
  DATA_LOCAL_PATH=$DATA_LOCAL_PATH \
  CONFIG_SHARED_PATH=$CONFIG_SHARED_PATH \
  CURRENT_UID=$CURRENT_UID \
  HOST_IP=$HOST_IP \
  docker-compose -f ./compose/infrastructure.yml -p kiuwan stop redis_00001 redis_00002 redis_00003 redis_00004 redis_00005 redis_00006 2>&1 | tee -a $LOG_FILE
}

stopMySQL() {
  PORTMYSQL=$PORTMYSQL \
  PORTAPACHEHTTP=$PORTAPACHEHTTP \
  PORTAPACHEHTTPS=$PORTAPACHEHTTPS \
  DATA_LOCAL_PATH=$DATA_LOCAL_PATH \
  CONFIG_SHARED_PATH=$CONFIG_SHARED_PATH \
  CURRENT_UID=$CURRENT_UID \
  HOST_IP=$HOST_IP \
  docker-compose -f ./compose/infrastructure.yml -p kiuwan stop mysqlkiuwan 2>&1 | tee -a $LOG_FILE
}

stopManual() {
  PORTMYSQL=$PORTMYSQL \
  PORTAPACHEHTTP=$PORTAPACHEHTTP \
  PORTAPACHEHTTPS=$PORTAPACHEHTTPS \
  DATA_LOCAL_PATH=$DATA_LOCAL_PATH \
  CONFIG_SHARED_PATH=$CONFIG_SHARED_PATH \
  CURRENT_UID=$CURRENT_UID \
  HOST_IP=$HOST_IP \
  docker-compose -f ./compose/infrastructure.yml -p kiuwan stop $MANUAL_SERVICE_INDICATED 2>&1 | tee -a $LOG_FILE
}

stopRunningContainers() {
  local label=$1
  local RUNNING_CONTAINERS=$(docker ps -a -q -f "label=${label}")
  if [ -n "$RUNNING_CONTAINERS" ]
  then
    docker stop $RUNNING_CONTAINERS 2>&1 | tee -a $LOG_FILE
  fi
}

if [ -n "$MANUAL_SERVICE_INDICATED" ]
then
  if [[ $MANUAL_SERVICE_INDICATED == "redis" ]]
  then
    stopRedis
    stopRunningContainers "com.kiuwan.onpremises.infrastructure.cache=true"
  else
    stopManual
  fi
else
  if [[ $EXTERNALIZE_REDIS_CACHE == "true" ]] || [[ $EXTERNALIZE_REDIS_STORAGE == "true" ]]
  then
    echo "Redis is externalized"
  else
    stopRedis
    stopRunningContainers "com.kiuwan.onpremises.infrastructure.cache=true"
  fi

  if [[ $EXTERNALIZE_APACHELOADBALANCER == "true" ]]
  then
    echo "ApacheLoadBalancer is externalized"
  else
    stopApache
    stopRunningContainers "com.kiuwan.onpremises.infrastructure.loadbalancer=true"
  fi

  if [[ $EXTERNALIZE_MYSQL == "true" ]]
  then
    echo "MySQL is externalized"
  else
    stopMySQL
    stopRunningContainers "com.kiuwan.onpremises.infrastructure.db=true"
  fi
fi

