#!/bin/bash
source ../tools/functions.sh
checkRoot

echo "-----------------------------------------------------------------------------------"
echo "Checking directory and file permissions before starting Kiuwan updater container."
echo "Note that when executing a full update some files or directories may not be found."
echo "New directories and files will be automatically created when updating your volumes."
echo "-----------------------------------------------------------------------------------"
source ../tools/check-permissions.sh

VOLUMES_PROPERTIES_FILE="../config/volumes.properties"
DATA_LOCAL_PATH=$(getProperty "data.local" $VOLUMES_PROPERTIES_FILE)
DATA_SHARED_PATH=$(getProperty "data.shared" $VOLUMES_PROPERTIES_FILE)
CONFIG_SHARED_PATH=$(getProperty "config.shared" $VOLUMES_PROPERTIES_FILE)
NEW_VERSION_VOLUMES_PATH="../../volumes"

abortIfDirNotFound "${DATA_LOCAL_PATH}"
abortIfDirNotFound "${DATA_SHARED_PATH}"
abortIfDirNotFound "${CONFIG_SHARED_PATH}"

source ./legacy/process-warnings.sh

LOG_FILE="../logs/update.log"
CURRENT_UID=$(getCurrentUid)

NEW_VERSION_VOLUMES_PATH=$NEW_VERSION_VOLUMES_PATH \
DATA_LOCAL_PATH=$DATA_LOCAL_PATH \
DATA_SHARED_PATH=$DATA_SHARED_PATH \
CONFIG_SHARED_PATH=$CONFIG_SHARED_PATH \
CURRENT_UID=$CURRENT_UID \
docker-compose -f ./compose/update.yml up --abort-on-container-exit 2>&1 | tee -a $LOG_FILE

docker_ps=$(docker ps -a -q --filter "label=com.kiuwan.onpremises.kiuwanupdater=true")
if [ -z "${docker_ps}" ] ; then
	echo Kiuwan updater container not found
	UPDATER_EXIT_CODE=0
else
	echo "Checking updater exit code for ${docker_ps}" 2>&1 | tee -a $LOG_FILE
	UPDATER_EXIT_CODE=$(docker inspect ${docker_ps} --format='{{.State.ExitCode}}')
fi
echo "Updater exit code = $UPDATER_EXIT_CODE" 2>&1 | tee -a $LOG_FILE

NEW_VERSION_VOLUMES_PATH=$NEW_VERSION_VOLUMES_PATH \
DATA_LOCAL_PATH=$DATA_LOCAL_PATH \
DATA_SHARED_PATH=$DATA_SHARED_PATH \
CONFIG_SHARED_PATH=$CONFIG_SHARED_PATH \
CURRENT_UID=$CURRENT_UID \
docker-compose -f ./compose/update.yml down 2>&1 | tee -a $LOG_FILE

docker info 2>&1 >> $LOG_FILE

exit $UPDATER_EXIT_CODE
