#!/bin/bash
source ./tools/functions.sh
checkRoot
CURRENTDIR=`pwd`

VOLUMES_PROPERTIES_FILE="./config/volumes.properties"
CONFIG_SHARED_PATH=$(getProperty "config.shared" $VOLUMES_PROPERTIES_FILE)
UPDATE_CLIENTS=$(getProperty "kiuwan.clients.update" $CONFIG_SHARED_PATH/globalConfig/globalConfig.properties)
if [[ $UPDATE_CLIENTS == "false" ]]
then
	echo "************************************************************************************"
	echo "************************************************************************************"
	echo "The kiuwan.clients.update flag in the \"$CONFIG_SHARED_PATH/globalConfig/globalConfig.properties\" file is set to \"false\"."
	echo "In order to execute this script you must change the value of that file".
	echo "If you change the value of that flag, your clients will be updated."
	echo "************************************************************************************"
	echo "************************************************************************************"
	exit 1;
fi

if [ "$1" == "ignore-prerequisites" ] ; then
	#shift rorate the first parameter to avoid spreading the parameter
	shift
	LOG_FILE="./logs/install.log"
	echo "pre-requisites will not be checked." 2>&1 | tee -a $LOG_FILE
else
	source ./check-prerequisites.sh
	if [ "$KOP_POSSIBLE_ERROR_ON_INSTALL" -eq "1" ]; then
		LOG_FILE="./logs/install.log"
		echo "The minimum requirements are not met." 2>&1 | tee -a $LOG_FILE
		echo "Aborting installation." 2>&1 | tee -a $LOG_FILE
		exit 1;
	fi
fi


LOG_FILE="../logs/install.log"

echo "******************************************************"
echo "FULL INSTALL KIUWAN"
echo "******************************************************"


cd ./docker
source ./create-network.sh 2>&1 | tee -a $LOG_FILE
source ./install-infrastructure.sh 2>&1 | tee -a $LOG_FILE
source ./start-infrastructure.sh 2>&1 | tee -a $LOG_FILE
source ./update.sh 2>&1 | tee -a $LOG_FILE
UPDATER_EXIT_CODE=${PIPESTATUS[0]}
if [ "$UPDATER_EXIT_CODE" -eq "0" ] ; then
	source ./start-kiuwan.sh 2>&1 | tee -a $LOG_FILE
	echo "******************************************************"
	echo "KIUWAN INSTALLED"
	echo "******************************************************"
else
	echo "******************************************************"
	echo "ERROR installing Kiuwan. Check if your system meets"
	echo "the requirements specified in the documentation."
	echo "Aborting installation. Please run uninstall.sh script"
	echo "before trying again."
	echo "******************************************************"
fi
docker info 2>&1 >> $LOG_FILE
cd $CURRENTDIR
