#!/bin/bash
source ../tools/functions.sh

kiuwan_domain="$1"

# Parameters validation
if [ -z "$1" ] ; then
	echo "kiuwan-cercopy.sh - copies the specified certificates to the user-content folder"
	echo
	echo "ERROR: please specify a kiuwan domain when calling this script, e.g.:"
	echo "./kiuwan-cercopy.sh kiuwan.mycompany.com"
	exit 1
fi

# Needed files
ca_crt_file=${kiuwan_domain}/cacert.pem
crt_file=${kiuwan_domain}/domaincert.pem
key_file=${kiuwan_domain}/domainkey.pem
jks_file=${kiuwan_domain}/domainkeystore.jks
truststore_file=${kiuwan_domain}/truststore.jks

# Check folders and files
abortIfDirNotFound "${kiuwan_domain}"
abortIfNotFound "${ca_crt_file}"
abortIfNotFound "${crt_file}"
abortIfNotFound "${key_file}"
abortIfNotFound "${jks_file}"
abortIfNotFound "${truststore_file}"

# Destination folder
user_content_target_dir="../user-content/certs"

# Copy generated files to user content directory
# Remove existing folder for the specified domain
echo Cleaning "${user_content_target_dir}" directory
rm -rf ${user_content_target_dir}
mkdir "${user_content_target_dir}/"

echo Copying files to "${user_content_target_dir}"
cp -v ${ca_crt_file} ${user_content_target_dir}
cp -v ${crt_file} ${user_content_target_dir}
cp -v ${key_file} ${user_content_target_dir}
cp -v ${jks_file} ${user_content_target_dir}
cp -v ${truststore_file} ${user_content_target_dir}

echo Done!
