#!/bin/bash
source ../tools/functions.sh
checkRoot

VOLUMES_PROPERTIES_FILE="../config/volumes.properties"

CONFIG_SHARED_PATH=$(getProperty "config.shared" $VOLUMES_PROPERTIES_FILE)
DATA_SHARED_PATH=$(getProperty "data.shared" $VOLUMES_PROPERTIES_FILE)
DATA_LOCAL_PATH=$(getProperty "data.local" $VOLUMES_PROPERTIES_FILE)

FIRST_PARAMETER=$1

echo "****************************************************************"
echo "Collecting support info from you Kiuwan On-Premises installation"
echo
echo "TIP: use ./collect-support-info.sh no-docker-logs to bypass"
echo "collecting all Kiuwan On-Premises Docker logs"
echo "****************************************************************"
CURRENTWORKINGDIR=`pwd`
DIR_NAME=$(date +"%Y%m%d%H%M%S")
mkdir $DIR_NAME

echo "Creating directories..."
mkdir "$DIR_NAME/config-shared"
mkdir "$DIR_NAME/config-shared/ApacheLoadBalancer"
mkdir "$DIR_NAME/config-shared/generatedConfig/"
mkdir "$DIR_NAME/config-shared/generatedConfig/analyzers"
mkdir "$DIR_NAME/config-shared/generatedConfig/front"
mkdir "$DIR_NAME/config-shared/generatedConfig/schedulers"
mkdir "$DIR_NAME/data-local"
mkdir "$DIR_NAME/data-local/MySql"
mkdir "$DIR_NAME/data-local/Redis"
mkdir "$DIR_NAME/data-local/Redis/data"
mkdir "$DIR_NAME/data-local/generatedConfig"
mkdir "$DIR_NAME/data-local/generatedConfig/analyzers"
mkdir "$DIR_NAME/data-local/generatedConfig/front"
mkdir "$DIR_NAME/data-local/generatedConfig/schedulers"
mkdir "$DIR_NAME/data-shared"
mkdir "$DIR_NAME/install"
mkdir "$DIR_NAME/networks"
mkdir "$DIR_NAME/dockerLogs"
mkdir "$DIR_NAME/dockerInfo"
mkdir "$DIR_NAME/iptablesInfo"
mkdir "$DIR_NAME/sysctl"

# Prerequisites
echo "Collecting prerequisites..."
cd ..
source ./check-prerequisites.sh >& "$CURRENTWORKINGDIR/$DIR_NAME/prerequisites.txt"
cd $CURRENTWORKINGDIR

# Install logs
echo "Collecting installation logs..."
cp -R "../logs/" "$DIR_NAME/install/"

# Shared logs
echo "Collecting support logs..."
cp -R "$DATA_SHARED_PATH/logs/" "$DIR_NAME/data-shared/"

# Version info
echo "Collecting version files..."
cp -R "$DATA_SHARED_PATH/publicData/versions" "$DIR_NAME/data-shared/"

# Apache and global config files
echo "Collecting configuration..."
cp -R "$CONFIG_SHARED_PATH/ApacheLoadBalancer/conf/" "$DIR_NAME/config-shared/ApacheLoadBalancer/"
cp -R "$CONFIG_SHARED_PATH/globalConfig/" "$DIR_NAME/config-shared/"

# Wildfly instances configuration (config-shared)
cd "$CONFIG_SHARED_PATH/generatedConfig/analyzers/"
ANALIZERS_CONFIG_PATHS=($(ls))
cd "$CURRENTWORKINGDIR"
for ANALIZER_CONFIG_PATH in "${ANALIZERS_CONFIG_PATHS[@]}"
do
	mkdir "$DIR_NAME/config-shared/generatedConfig/analyzers/$ANALIZER_CONFIG_PATH"
	cp -R "$CONFIG_SHARED_PATH/generatedConfig/analyzers/$ANALIZER_CONFIG_PATH/config" "$DIR_NAME/config-shared/generatedConfig/analyzers/$ANALIZER_CONFIG_PATH"
done

cd "$CONFIG_SHARED_PATH/generatedConfig/front/"
FRONT_CONFIG_PATHS=($(ls))
cd "$CURRENTWORKINGDIR"
for FRONT_CONFIG_PATH in "${FRONT_CONFIG_PATHS[@]}"
do
	mkdir "$DIR_NAME/config-shared/generatedConfig/front/$FRONT_CONFIG_PATH"
	cp -R "$CONFIG_SHARED_PATH/generatedConfig/front/$FRONT_CONFIG_PATH/config" "$DIR_NAME/config-shared/generatedConfig/front/$FRONT_CONFIG_PATH"
done

cd "$CONFIG_SHARED_PATH/generatedConfig/schedulers/"
SCHEDULERS_CONFIG_PATHS=($(ls))
cd "$CURRENTWORKINGDIR"
for SCHEDULER_CONFIG_PATH in "${SCHEDULERS_CONFIG_PATHS[@]}"
do
	mkdir "$DIR_NAME/config-shared/generatedConfig/schedulers/$SCHEDULER_CONFIG_PATH"
	cp -R "$CONFIG_SHARED_PATH/generatedConfig/schedulers/$SCHEDULER_CONFIG_PATH/config" "$DIR_NAME/config-shared/generatedConfig/schedulers/$SCHEDULER_CONFIG_PATH"
done

# Apache, updater and MySQL logs
echo "Collecting local logs..."
cp -R "$DATA_LOCAL_PATH/ApacheLoadBalancer/" "$DIR_NAME/data-local/ApacheLoadBalancer/"
cp -R "$DATA_LOCAL_PATH/updater/" "$DIR_NAME/data-local/updater/"
cp -R "$DATA_LOCAL_PATH/MySql/logs/" "$DIR_NAME/data-local/MySql/logs/"

# Redis nodes configuration
echo "Collecting Redis local configuration..."
rsync -a --include="*/" --include="nodes.conf*" --exclude="*" $DATA_LOCAL_PATH/Redis/data/ $DIR_NAME/data-local/Redis/data

# Wildfly instances configuration (data-local)
echo "Collecting Wildfly instances configuration..."
cd "$DATA_LOCAL_PATH/generatedConfig/analyzers/"
ANALIZERS_DATA_PATHS=($(ls))
cd "$CURRENTWORKINGDIR"
for ANALIZER_DATA_PATH in "${ANALIZERS_DATA_PATHS[@]}"
do
	mkdir "$DIR_NAME/data-local/generatedConfig/analyzers/$ANALIZER_DATA_PATH"
	cp -R "$DATA_LOCAL_PATH/generatedConfig/analyzers/$ANALIZER_DATA_PATH/logs/" "$DIR_NAME/data-local/generatedConfig/analyzers/$ANALIZER_DATA_PATH/logs/"
done

cd "$DATA_LOCAL_PATH/generatedConfig/front/"
FRONT_DATA_PATHS=($(ls))
cd "$CURRENTWORKINGDIR"
for FRONT_DATA_PATH in "${FRONT_DATA_PATHS[@]}"
do
	mkdir "$DIR_NAME/data-local/generatedConfig/front/$FRONT_DATA_PATH"
	cp -R "$DATA_LOCAL_PATH/generatedConfig/front/$FRONT_DATA_PATH/logs/" "$DIR_NAME/data-local/generatedConfig/front/$FRONT_DATA_PATH/logs/"
done

cd "$DATA_LOCAL_PATH/generatedConfig/schedulers/"
SCHEDULERS_DATA_PATHS=($(ls))
cd "$CURRENTWORKINGDIR"
for SCHEDULER_DATA_PATH in "${SCHEDULERS_DATA_PATHS[@]}"
do
	mkdir "$DIR_NAME/data-local/generatedConfig/schedulers/$SCHEDULER_DATA_PATH"
	cp -R "$DATA_LOCAL_PATH/generatedConfig/schedulers/$SCHEDULER_DATA_PATH/logs/" "$DIR_NAME/data-local/generatedConfig/schedulers/$SCHEDULER_DATA_PATH/logs/"
done

# List all files
echo "Collecting volumes file list..."
find $CONFIG_SHARED_PATH > "$DIR_NAME/config-shared-files.txt"
find $DATA_SHARED_PATH > "$DIR_NAME/data-shared-files.txt"
find $DATA_LOCAL_PATH > "$DIR_NAME/data-local-files.txt"

# Docker containers list
docker ps -a > "$DIR_NAME/docker-ps-a.txt"

# Docker networks
echo "Collecting Docker network data..."
DOCKER_NETWORKS_IDS=($(docker network ls --format {{.ID}}))
for DOCKER_NETWORKS_ID in "${DOCKER_NETWORKS_IDS[@]}"
do
	docker network inspect $DOCKER_NETWORKS_ID > "$DIR_NAME/networks/docker-network-$DOCKER_NETWORKS_ID.txt"
done

# IP info (ifconfig and ip addr)
echo "Collecting ip info..."
command -v ifconfig > /dev/null 2>&1
commandAvailable=$?
if [ $commandAvailable -eq 0 ]; then
	ifconfig >& "$DIR_NAME/networks/ipinfo.txt"
fi

command -v ip > /dev/null 2>&1
commandAvailable=$?
if [ $commandAvailable -eq 0 ]; then
	ip addr >> "$DIR_NAME/networks/ipinfo.txt"
fi

# KoP containers logs and config
DOCKER_KIUWAN_CONTAINERS_IDS=($(docker ps -a -q --filter "label=com.kiuwan.onpremises=true"))

if [ "$FIRST_PARAMETER" == "no-docker-logs" ]
then
	echo "Kiuwan On-Premises containers logs will not be collected (no-docker-logs option detected)"
else
	echo "Collecting Kiuwan On-Premises containers logs..."
	for DOCKER_KIUWAN_CONTAINERS_ID in "${DOCKER_KIUWAN_CONTAINERS_IDS[@]}"
	do
		docker logs $DOCKER_KIUWAN_CONTAINERS_ID >& "$DIR_NAME/dockerLogs/docker-logs-container-$DOCKER_KIUWAN_CONTAINERS_ID.txt"
	done
fi

echo "Collecting Kiuwan On-Premises containers configuration..."
for DOCKER_KIUWAN_CONTAINERS_ID in "${DOCKER_KIUWAN_CONTAINERS_IDS[@]}"
do
	docker inspect $DOCKER_KIUWAN_CONTAINERS_ID > "$DIR_NAME/dockerLogs/docker-inspect-container-$DOCKER_KIUWAN_CONTAINERS_ID.txt"
done

# Other docker and system info

echo "Collecting image versions..."
docker images > "$DIR_NAME/dockerImages.txt"

echo "Collecting image digests..."
docker image ls --all --digests > "$DIR_NAME/dockerImagesAllDigests.txt"

echo "Collecting ip tables info..."
iptables -L > "$DIR_NAME/iptablesInfo/iptablesL.txt"
iptables -S > "$DIR_NAME/iptablesInfo/iptablesS.txt"

echo "Collecting sysctl info..."
sysctl -a >& "$DIR_NAME/sysctl/sysctla.txt"

echo "Collecting environment variables..."
env > "$DIR_NAME/dockerInfo/env.txt"
printenv > "$DIR_NAME/dockerInfo/printenv.txt"

echo "Collecting Docker proxy configuration..."
cat /etc/systemd/system/docker.service.d/http-proxy.conf >& "$DIR_NAME/dockerInfo/http-proxy.conf.txt"
cat ~/.docker/config.json >& "$DIR_NAME/dockerInfo/docker.config.json.txt"

echo "****************************************************************"
echo "Finished retrieving support information."
echo "You can now send lease send to Kiuwan support files found here:"
echo "$CURRENTWORKINGDIR/$DIR_NAME"
echo "****************************************************************"
