#!/bin/bash

function checkPortIsNotUsed {
	#1-65535
	local PORT=$1
	#Protocol= tcp, udp,udp6...
	local PROTOCOL=$2
	#netstat -tlu -n --numeric-ports | grep "udp " | grep ":5353 " | wc -l
	PORT_USED=`netstat -tlu -n --numeric-ports | grep "${PROTOCOL} " | grep ":${PORT} " | wc -l `
	#If PORT_USED=0, port is not used
	echo $PORT_USED
}

function checkUrlconnectivity  {
	local URL=$1
	wget -q --spider ${URL}
	URL_CONNECTION=$?
	#If URL_CONNECTION=0, connetion is OK
	echo $URL_CONNECTION
}

function checkDockerconnectivity  {
	local IMAGE=$1
	docker pull -q $IMAGE >/dev/null 2>&1
	CORRECT=$?
	#If CORRECT=0, connetion is OK
	docker rmi $IMAGE >/dev/null 2>&1
	echo $CORRECT

}

function getFreeSpaceAvailableInDirectory  {
	local DIRECTORY=$1
	FREE_SPACE=$(df -h --output=avail $DIRECTORY | tail -1)
	echo $FREE_SPACE
}

function checkCommandExists  {
	local COMMAND=$1
	COMMAND_RESULT=$(command -v $COMMAND)
	COMMAND_RESULT=$?
	echo $COMMAND_RESULT
}

function getFreeMemAvailable {
	local FREEMEM=$(cat /proc/meminfo | grep MemFree | cut -f2 -d: | xargs | cut -d ' ' -f 1 | xargs)
	FREEMEM=$(echo "scale=2; $((FREEMEM))/1024/1024" | bc)
	#Return free ram in GB
	echo $FREEMEM
}

function getVersionNumber {
	local COMMAND_VERSION_OUTPUT=$1
	COMMAND_REGEXP_VERSION="([0-9]+\.?)+"
	if [[ $COMMAND_VERSION_OUTPUT =~ $COMMAND_REGEXP_VERSION ]]; then
		echo ${BASH_REMATCH[0]}
	else
		echo "Version not detected"
	fi
}

function versionHigher () {
    if [[ $1 == $2 ]]
    then
        return 0
    fi
    local IFS=.
    local i ver1=($1) ver2=($2)
    # fill empty fields in ver1 with zeros
    for ((i=${#ver1[@]}; i<${#ver2[@]}; i++))
    do
        ver1[i]=0
    done
    for ((i=0; i<${#ver1[@]}; i++))
    do
        if [[ -z ${ver2[i]} ]]
        then
            # fill empty fields in ver2 with zeros
            ver2[i]=0
        fi
        if ((10#${ver1[i]} > 10#${ver2[i]}))
        then
            return 1
        fi
        if ((10#${ver1[i]} < 10#${ver2[i]}))
        then
            return 2
        fi
    done
    return 0
}

function getFileSystemType  {
	local DIRECTORY=$1
	FILE_SYSTEM_TYPE=$(df --output=fstype $DIRECTORY | tail -1)
	echo $FILE_SYSTEM_TYPE
}

function getSupportDType  {
	SUPPORTDTYPE=$(docker info -f "{{json .DriverStatus}}" | grep "\"Supports d_type\",\"true\"")
	echo $?
}

function getFtypeXFSSupport {
	local DIRECTORY=$1
	SUPPORTDTYPE=$(xfs_info $DIRECTORY  | grep "ftype=0")
	echo $?
}
