#!/bin/bash

function getProperty {
	local prop_key=$1
	local prop_value=`cat $2 | grep "^$prop_key=.*$" | cut -d'=' -f2-`
	echo "${prop_value}"
}

function checkIfFileExist {
	if [ ! -f "$1" ] ; then
		echo "false"
	else
		echo "true"
	fi
}

function abortIfNotFound {
	if [ ! -f "$1" ] ; then
		echo File "$1" not found, aborting
		exit 1
	fi
}

function abortIfDirNotFound {
	if [ ! -d "$1" ] ; then
		echo Dir "$1" not found, aborting
		exit 1
	fi
}

function checkRoot {
	if [[ $(id -u) -ne 0 ]] ; then
		echo "Please run as root"
		exit 1
	fi
}

function abortIfCommandNotExists {
	local command=$1
	local error_message=$2
	if hash "$command" 2>/dev/null ; then
		echo "$command" found
	else
		if [ -z "$2" ] ; then
			echo "$1 not found, aborting"
		else
			echo "$error_message"
		fi
		exit 1
	fi
}

function getPermissionFromFile {
	local fileName=$1
	local filePermissionsDist=$2
	#echo $filePermissionsDist
	local filePermission=`cat $filePermissionsDist | grep -P "^f\t$fileName\t" | cut -f 3`
	echo "${filePermission}"
}

function getPermissionFromDir {
	local dirName=$1
	local filePermissionsDist=$2
	#echo $filePermissionsDist
	local dirPermission=`cat $filePermissionsDist | grep -P "^d\t$dirName\t" | cut -f 3`
	echo "${dirPermission}"
}

function checkAllDirPermissions {
	local installationHome=$1
	local filePermissionsDist=$2
	#echo $filePermissionsDist
	local dirList=($(cat $filePermissionsDist | grep -P "^d" | cut -f2))
	for currentDir in "${dirList[@]}"
	do
		#echo "--$currentDir"
		pushd $installationHome > /dev/null
		currentDirPermissions=$(find . -maxdepth 5 -printf '%y\t%p\t%m\n' | grep -P "^d\t$currentDir\t" | cut -f 3)
		popd > /dev/null
		currentDirPermissionsCorrect=$(getPermissionFromDir $currentDir $filePermissionsDist)
		#echo "++$currentDirPermissions"
		#echo "**$currentDirPermissionsCorrect"
		if [ -z "$currentDirPermissions" ] ; then
			echo "Directory not found while checking permissions: $currentDir"
		else
			if [ $currentDirPermissions -ne $currentDirPermissionsCorrect ] ; then
				echo "Replacing $currentDirPermissions with $currentDirPermissionsCorrect for directory $currentDir"
				pushd $installationHome > /dev/null
				chmod $currentDirPermissionsCorrect $currentDir
				popd > /dev/null
				echo "Directory permissions modified"
			fi
		fi
	done
	#echo "--$currentInstallationPermissions"
}


function checkAllFilePermissions {
	local installationHome=$1
	local filePermissionsDist=$2
	#echo $filePermissionsDist
	local fileList=($(cat $filePermissionsDist | grep -P "^f" | cut -f2))
	for currentFile in "${fileList[@]}"
	do
		#echo "--$currentFile"
		pushd $installationHome > /dev/null
		currentFilePermissions=$(find . -maxdepth 5 -printf '%y\t%p\t%m\n' | grep -P "^f\t$currentFile\t" | cut -f 3)
		popd > /dev/null
		currentFilePermissionsCorrect=$(getPermissionFromFile $currentFile $filePermissionsDist)
		#echo "++$currentFilePermissions"
		#echo "**$currentFilePermissionsCorrect"
		if [ -z "$currentFilePermissions" ] ; then
			echo "File not found while checking permissions: $currentFile"
		else
			if [ $currentFilePermissions -ne $currentFilePermissionsCorrect ] ; then
				echo "Replacing $currentFilePermissions with $currentFilePermissionsCorrect for file $currentFile"
				pushd $installationHome > /dev/null
				chmod $currentFilePermissionsCorrect $currentFile
				popd > /dev/null
				echo "File permissions modified"
			fi
		fi
	done
	#echo "--$currentInstallationPermissions"
}

function configureMySqlUserAndPass {
	FILE_BACKUP=$1
	FILE=$2
	USER=$3
	PASSWORD=$4
	cp -f $FILE_BACKUP $FILE
	sed -i 's/{{mysqluser}}/'$USER'/g' $FILE
	sed -i 's/{{mysqlpassword}}/'$PASSWORD'/g' $FILE
}

function getCurrentUid {
	local currentUid=`id -u`:`id -g`
	echo $currentUid
}

function getHostIp {
	local currentIp=`ip route get 1 | sed -n 's/^.*src \([0-9.]*\) .*$/\1/p'`
	echo $currentIp
}
