#!/bin/bash
source ./tools/functions.sh
checkRoot

FIRST_PARAMETER=$1

VOLUMES_PROPERTIES_FILE="./config/volumes.properties"
CONFIG_SHARED_PATH=$(getProperty "config.shared" $VOLUMES_PROPERTIES_FILE)
DATA_SHARED_PATH=$(getProperty "data.shared" $VOLUMES_PROPERTIES_FILE)
DATA_LOCAL_PATH=$(getProperty "data.local" $VOLUMES_PROPERTIES_FILE)
LOG_FILE="./logs/uninstall.log"

echo "******************************************************"
echo "UNINSTALL KIUWAN"
echo "******************************************************"

docker_ps=$(docker ps -a -q -f "label=com.kiuwan.onpremises=true")
if [ -z "${docker_ps}" ] ; then
	echo No remaining kiuwan containers to stop
else
	echo Stopping containers with ids ${docker_ps} 2>&1 | tee -a $LOG_FILE
	docker stop ${docker_ps} 2>&1 | tee -a $LOG_FILE
fi

echo Prunning kiuwan containers...
docker container prune --force --filter "label=com.kiuwan.onpremises=true" 2>&1 | tee -a $LOG_FILE

echo Prunning kiuwan networks...
docker network prune --force --filter=label="com.kiuwan.onpremises=true" 2>&1 | tee -a $LOG_FILE


if [ "$FIRST_PARAMETER" == "delete-volumes" ]
then
	rm -rf $CONFIG_SHARED_PATH
	rm -rf $DATA_SHARED_PATH
	rm -rf $DATA_LOCAL_PATH
	echo "Volumes DELETED"
else
	echo
	echo "************************ IMPORTANT ******************************"
	echo "Current volumes folders have NOT been removed just in case"
	echo "you need to preserve any of the information stored there."
	echo
	echo "CONFIG_SHARED_PATH current location:"
	echo ${CONFIG_SHARED_PATH}
	echo
	echo "DATA_SHARED_PATH current location:"
	echo ${DATA_SHARED_PATH}
	echo
	echo "DATA_LOCAL_PATH current location:"
	echo ${DATA_LOCAL_PATH}
	echo
	echo "You should choose one of these options BEFORE installing again:"
	echo "- Use the same volumes paths: delete the current folders and"
	echo "  recreate it with a fresh copy of the supplied volumes."
	echo "- Use different volumes paths: update the configuration file"
	echo "  config/volumes.properties and create a new copy of"
	echo "  the supplied volumes."
	echo "- Keep all configuration but not the data: just recreate"
	echo "  or remove the data volumes (DATA_SHARED_PATH and"
	echo "  DATA_LOCAL_PATH). This option will keep your configuration "
	echo "  untouched"
	echo "- Perform a full uninstall, including volumes removal. To do so,"
	echo "  run sudo ./uninstall.sh delete-volumes"
	echo "*****************************************************************"
fi
