#!/bin/bash
source ./tools/functions.sh
checkRoot

LOG_FILE="../logs/update-full.log"
source ./check-prerequisites.sh --isUpdate
echo "******************************************************"
echo "FULL UPDATE KIUWAN"
echo "******************************************************"
CURRENTDIR=`pwd`

VOLUMES_PROPERTIES_FILE="./config/volumes.properties"
CONFIG_SHARED_PATH=$(getProperty "config.shared" $VOLUMES_PROPERTIES_FILE)
UPDATE_CLIENTS=$(getProperty "kiuwan.clients.update" $CONFIG_SHARED_PATH/globalConfig/globalConfig.properties)
if [[ $UPDATE_CLIENTS == "false" ]]
then
	echo "************************************************************************************"
	echo "************************************************************************************"
	echo "The kiuwan.clients.update flag in the \"$CONFIG_SHARED_PATH/globalConfig/globalConfig.properties\" file is set to \"false\"."
	echo "In order to execute this script you must change the value of that file".
	echo "If you change the value of that flag, your clients will be updated."
	echo "************************************************************************************"
	echo "************************************************************************************"
	exit 1;
fi

source ./tools/process-warnings.sh

cd ./docker
source ./stop-kiuwan.sh 2>&1 | tee -a $LOG_FILE
source ./update.sh 2>&1 | tee -a $LOG_FILE
UPDATER_EXIT_CODE=${PIPESTATUS[0]}
if [ "$UPDATER_EXIT_CODE" -eq "0" ] ; then
	source ./stop-infrastructure.sh apacheloadbalancer 2>&1 | tee -a $LOG_FILE
	source ./start-infrastructure.sh apacheloadbalancer 2>&1 | tee -a $LOG_FILE
	source ./start-kiuwan.sh 2>&1 | tee -a $LOG_FILE
	echo "******************************************************"
	echo "FULL UPDATE KIUWAN FINISHED"
	echo "******************************************************"
else
	echo "******************************************************"
	echo "ERROR updating Kiuwan. Check if your system meets"
	echo "the requirements specified in the documentation."
	echo "******************************************************"
fi

cd $CURRENTDIR
